﻿using BlacksmithWorkshopContracts.BindingModels;
using BlacksmithWorkshopContracts.ViewModels;
using BlacksmithWorkshopDataModels.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BlacksmithWorkshopListImplement.Models
{
    //класс реализующий интерфейс модели изделия
    public class Article : IArticleModel
    {
        //методы set делаем приватным, чтобы исключить неразрешённые манипуляции
        public int Id { get; private set; }

        public string ArticleName { get; private set; } = string.Empty;

        public double Price { get; private set; }

        public Dictionary<int, (IWorkPieceModel, int)> ArticleWorkPiece { get; private set; } = new Dictionary<int, (IWorkPieceModel, int)>();

        //метод для создания объекта от класса-компонента на основе класса-BindingModel
        public static Article? Create(ArticleBindingModel? model)
        {
            if (model == null)
            {
                return null;
            }

            return new Article()
            {
                Id = model.Id,
                ArticleName = model.ArticleName,
                Price = model.Price,
                ArticleWorkPiece = model.ArticleWorkPiece
            };
        }

        //метод изменения существующего объекта
        public void Update(ArticleBindingModel? model)
        {
            if (model == null)
            {
                return;
            }

            ArticleName = model.ArticleName;
            Price = model.Price;
            ArticleWorkPiece = model.ArticleWorkPiece;
        }

        //метод для создания объекта класса ViewModel на основе данных объекта класса-компонента
        public ArticleViewModel GetViewModel() => new()
        {
            Id = Id,
            ArticleName = ArticleName,
            Price = Price,
            ArticleWorkPiece = ArticleWorkPiece
        };
    }
}
